@@ -9,7 +9,8 @@ from calibre.customize import (CatalogPlugin, FileTypePlugin, PluginNotFound,
                               MetadataReaderPlugin, MetadataWriterPlugin,
                               InterfaceActionBase as InterfaceAction,
                               PreferencesPlugin, platform, InvalidPlugin,
-                              StoreBase as Store, ViewerPlugin, EditBookToolPlugin)
+                              StoreBase as Store, ViewerPlugin, EditBookToolPlugin,
+                              LibraryClosedPlugin)
 from calibre.customize.conversion import InputFormatPlugin, OutputFormatPlugin
 from calibre.customize.zipplugin import loader
 from calibre.customize.profiles import InputProfile, OutputProfile
@@ -246,6 +247,23 @@ def preferences_plugins():
                 yield plugin
 # }}}
 
+# Library Closed Plugins # {{{
+def available_library_closed_plugins():
+    customization = config['plugin_customization']
+    for plugin in _initialized_plugins:
+        if isinstance(plugin, LibraryClosedPlugin):
+            if not is_disabled(plugin):
+                plugin.site_customization = customization.get(plugin.name, '')
+                yield plugin
+
+def has_library_closed_plugins():
+    for plugin in _initialized_plugins:
+        if isinstance(plugin, LibraryClosedPlugin):
+            if not is_disabled(plugin):
+                return True
+    return False
+# }}}
+
 # Store Plugins # {{{
 
 def store_plugins():
@@ -446,14 +464,14 @@ def plugin_for_input_format(fmt):
             return plugin
 
 def all_input_formats():
-    formats = set([])
+    formats = set()
     for plugin in input_format_plugins():
         for format in plugin.file_types:
             formats.add(format)
     return formats
 
 def available_input_formats():
-    formats = set([])
+    formats = set()
     for plugin in input_format_plugins():
         if not is_disabled(plugin):
             for format in plugin.file_types:
@@ -695,7 +713,10 @@ def main(args=sys.argv):
     if opts.disable_plugin is not None:
         disable_plugin(opts.disable_plugin.strip())
     if opts.list_plugins:
-        fmt = '%-15s%-20s%-15s%-15s%s'
+        type_len = name_len = 0
+        for plugin in initialized_plugins():
+            type_len, name_len = max(type_len, len(plugin.type)), max(name_len, len(plugin.name))
+        fmt = '%-{}s%-{}s%-15s%-15s%s'.format(type_len+1, name_len+1)
         print fmt%tuple(('Type|Name|Version|Disabled|Site Customization'.split('|')))
         print
         for plugin in initialized_plugins():
