@@ -67,6 +67,7 @@ class Polish(QDialog):  # {{{
             'jacket':_('<h3>Book Jacket</h3>%s')%HELP['jacket'],
             'remove_jacket':_('<h3>Remove Book Jacket</h3>%s')%HELP['remove_jacket'],
             'remove_unused_css':_('<h3>Remove unused CSS rules</h3>%s')%HELP['remove_unused_css'],
+            'compress_images': _('<h3>Losslessly compress images</h3>%s') % HELP['compress_images'],
         }
 
         self.l = l = QGridLayout()
@@ -85,6 +86,7 @@ class Polish(QDialog):  # {{{
             ('jacket', _('Add/Replace metadata as a "book &jacket" page')),
             ('remove_jacket', _('&Remove a previously inserted book jacket')),
             ('remove_unused_css', _('Remove &unused CSS rules from the book')),
+            ('compress_images', _('Losslessly compress images')),
         ])
         prefs = gprefs.get('polishing_settings', {})
         for name, text in self.all_actions.iteritems():
